@@ -1,6 +1,6 @@
 package Mojolicious::Plugin::TtRenderer::Engine;
 {
-  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.42_01';
+  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.42_02';
 }
 
 use warnings;
@@ -50,12 +50,6 @@ sub _init {
     my %config = (
         INCLUDE_PATH => \@renderer_paths,
         COMPILE_EXT  => '.ttc',
-        # TODO maybe this should be File::Spec->catdir(File::Spec->tmpdir, $<)
-        COMPILE_DIR  => ($dir || do {
-          my $dir = File::Spec->catdir(File::Spec->tmpdir, "ttr$<");
-          mkdir $dir;
-          $dir;
-        }),
         UNICODE      => 1,
         ENCODING     => 'utf-8',
         CACHE_SIZE   => 128,
@@ -63,6 +57,12 @@ sub _init {
         %{$args{template_options} || {}},
     );
 
+    $config{COMPILE_DIR} //= $dir || do {
+      my $tmpdir = File::Spec->catdir(File::Spec->tmpdir, "ttr$<");
+      mkdir $tmpdir unless -d $tmpdir;
+      $tmpdir;
+    };
+
     $config{LOAD_TEMPLATES} =
       [Mojolicious::Plugin::TtRenderer::Provider->new(%config, renderer => $app->renderer)]
       unless $config{LOAD_TEMPLATES};
